@@ -10,8 +10,8 @@ EARTH_RADIUS = Variable(6_378e3, "Radius of Earth (m)")
 
 
 def plot_earth(initial=EARTH_POS, mag=4):
-    x = np.linspace(-mag*EARTH_RADIUS, mag*EARTH_RADIUS, 18)
-    y = np.linspace(-mag*EARTH_RADIUS, mag*EARTH_RADIUS, 18)
+    x = np.linspace(-mag*EARTH_RADIUS, mag*EARTH_RADIUS, mag*2+1)
+    y = np.linspace(-mag*EARTH_RADIUS, mag*EARTH_RADIUS, mag*2+1)
     X, Y = np.meshgrid(x, y)
 
     # calculate magntitude of gravity arrows
